@@ -11,6 +11,7 @@ Usage::
         ListNamespacesPaginator,
         ListRecoveryPointsPaginator,
         ListSnapshotsPaginator,
+        ListTableRestoreStatusPaginator,
         ListUsageLimitsPaginator,
         ListWorkgroupsPaginator,
         RedshiftServerlessClient,
@@ -23,6 +24,7 @@ Usage::
     list_namespaces_paginator: ListNamespacesPaginator = client.get_paginator("list_namespaces")
     list_recovery_points_paginator: ListRecoveryPointsPaginator = client.get_paginator("list_recovery_points")
     list_snapshots_paginator: ListSnapshotsPaginator = client.get_paginator("list_snapshots")
+    list_table_restore_status_paginator: ListTableRestoreStatusPaginator = client.get_paginator("list_table_restore_status")
     list_usage_limits_paginator: ListUsageLimitsPaginator = client.get_paginator("list_usage_limits")
     list_workgroups_paginator: ListWorkgroupsPaginator = client.get_paginator("list_workgroups")
     ```
@@ -33,6 +35,7 @@ from .paginator import (
     ListNamespacesPaginator,
     ListRecoveryPointsPaginator,
     ListSnapshotsPaginator,
+    ListTableRestoreStatusPaginator,
     ListUsageLimitsPaginator,
     ListWorkgroupsPaginator,
 )
@@ -46,6 +49,7 @@ __all__ = (
     "ListNamespacesPaginator",
     "ListRecoveryPointsPaginator",
     "ListSnapshotsPaginator",
+    "ListTableRestoreStatusPaginator",
     "ListUsageLimitsPaginator",
     "ListWorkgroupsPaginator",
     "RedshiftServerlessClient",
