@@ -30,6 +30,7 @@ from .paginator import (
     ListNamespacesPaginator,
     ListRecoveryPointsPaginator,
     ListSnapshotsPaginator,
+    ListTableRestoreStatusPaginator,
     ListUsageLimitsPaginator,
     ListWorkgroupsPaginator,
 )
@@ -52,18 +53,21 @@ from .type_defs import (
     GetRecoveryPointResponseTypeDef,
     GetResourcePolicyResponseTypeDef,
     GetSnapshotResponseTypeDef,
+    GetTableRestoreStatusResponseTypeDef,
     GetUsageLimitResponseTypeDef,
     GetWorkgroupResponseTypeDef,
     ListEndpointAccessResponseTypeDef,
     ListNamespacesResponseTypeDef,
     ListRecoveryPointsResponseTypeDef,
     ListSnapshotsResponseTypeDef,
+    ListTableRestoreStatusResponseTypeDef,
     ListTagsForResourceResponseTypeDef,
     ListUsageLimitsResponseTypeDef,
     ListWorkgroupsResponseTypeDef,
     PutResourcePolicyResponseTypeDef,
     RestoreFromRecoveryPointResponseTypeDef,
     RestoreFromSnapshotResponseTypeDef,
+    RestoreTableFromSnapshotResponseTypeDef,
     TagTypeDef,
     UpdateEndpointAccessResponseTypeDef,
     UpdateNamespaceResponseTypeDef,
@@ -137,7 +141,12 @@ class RedshiftServerlessClient(BaseClient):
         """
 
     def convert_recovery_point_to_snapshot(
-        self, *, recoveryPointId: str, snapshotName: str, retentionPeriod: int = ...
+        self,
+        *,
+        recoveryPointId: str,
+        snapshotName: str,
+        retentionPeriod: int = ...,
+        tags: Sequence[TagTypeDef] = ...
     ) -> ConvertRecoveryPointToSnapshotResponseTypeDef:
         """
         Converts a recovery point to a snapshot.
@@ -182,7 +191,12 @@ class RedshiftServerlessClient(BaseClient):
         """
 
     def create_snapshot(
-        self, *, namespaceName: str, snapshotName: str, retentionPeriod: int = ...
+        self,
+        *,
+        namespaceName: str,
+        snapshotName: str,
+        retentionPeriod: int = ...,
+        tags: Sequence[TagTypeDef] = ...
     ) -> CreateSnapshotResponseTypeDef:
         """
         Creates a snapshot of all databases in a namespace.
@@ -215,6 +229,7 @@ class RedshiftServerlessClient(BaseClient):
         baseCapacity: int = ...,
         configParameters: Sequence[ConfigParameterTypeDef] = ...,
         enhancedVpcRouting: bool = ...,
+        port: int = ...,
         publiclyAccessible: bool = ...,
         securityGroupIds: Sequence[str] = ...,
         subnetIds: Sequence[str] = ...,
@@ -348,6 +363,16 @@ class RedshiftServerlessClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_redshift_serverless/client/#get_snapshot)
         """
 
+    def get_table_restore_status(
+        self, *, tableRestoreRequestId: str
+    ) -> GetTableRestoreStatusResponseTypeDef:
+        """
+        Returns information about a `TableRestoreStatus` object.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/redshift-serverless.html#RedshiftServerless.Client.get_table_restore_status)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_redshift_serverless/client/#get_table_restore_status)
+        """
+
     def get_usage_limit(self, *, usageLimitId: str) -> GetUsageLimitResponseTypeDef:
         """
         Returns information about a usage limit.
@@ -394,6 +419,7 @@ class RedshiftServerlessClient(BaseClient):
         *,
         endTime: Union[datetime, str] = ...,
         maxResults: int = ...,
+        namespaceArn: str = ...,
         namespaceName: str = ...,
         nextToken: str = ...,
         startTime: Union[datetime, str] = ...
@@ -423,6 +449,21 @@ class RedshiftServerlessClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_redshift_serverless/client/#list_snapshots)
         """
 
+    def list_table_restore_status(
+        self,
+        *,
+        maxResults: int = ...,
+        namespaceName: str = ...,
+        nextToken: str = ...,
+        workgroupName: str = ...
+    ) -> ListTableRestoreStatusResponseTypeDef:
+        """
+        Returns information about an array of `TableRestoreStatus` objects.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/redshift-serverless.html#RedshiftServerless.Client.list_table_restore_status)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_redshift_serverless/client/#list_table_restore_status)
+        """
+
     def list_tags_for_resource(self, *, resourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
         Lists the tags assigned to a resource.
@@ -492,6 +533,27 @@ class RedshiftServerlessClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_redshift_serverless/client/#restore_from_snapshot)
         """
 
+    def restore_table_from_snapshot(
+        self,
+        *,
+        namespaceName: str,
+        newTableName: str,
+        snapshotName: str,
+        sourceDatabaseName: str,
+        sourceTableName: str,
+        workgroupName: str,
+        activateCaseSensitiveIdentifier: bool = ...,
+        sourceSchemaName: str = ...,
+        targetDatabaseName: str = ...,
+        targetSchemaName: str = ...
+    ) -> RestoreTableFromSnapshotResponseTypeDef:
+        """
+        Restores a table from a snapshot to your Amazon Redshift Serverless instance.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/redshift-serverless.html#RedshiftServerless.Client.restore_table_from_snapshot)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_redshift_serverless/client/#restore_table_from_snapshot)
+        """
+
     def tag_resource(self, *, resourceArn: str, tags: Sequence[TagTypeDef]) -> Dict[str, Any]:
         """
         Assigns one or more tags to a resource.
@@ -567,6 +629,7 @@ class RedshiftServerlessClient(BaseClient):
         baseCapacity: int = ...,
         configParameters: Sequence[ConfigParameterTypeDef] = ...,
         enhancedVpcRouting: bool = ...,
+        port: int = ...,
         publiclyAccessible: bool = ...,
         securityGroupIds: Sequence[str] = ...,
         subnetIds: Sequence[str] = ...
@@ -610,6 +673,15 @@ class RedshiftServerlessClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_redshift_serverless/client/#get_paginator)
         """
 
+    @overload
+    def get_paginator(
+        self, operation_name: Literal["list_table_restore_status"]
+    ) -> ListTableRestoreStatusPaginator:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/redshift-serverless.html#RedshiftServerless.Client.get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_redshift_serverless/client/#get_paginator)
+        """
+
     @overload
     def get_paginator(
         self, operation_name: Literal["list_usage_limits"]
