@@ -33,13 +33,11 @@ else:
 
 __all__ = (
     "ConfigParameterTypeDef",
-    "ConvertRecoveryPointToSnapshotRequestRequestTypeDef",
+    "TagTypeDef",
     "ResponseMetadataTypeDef",
     "SnapshotTypeDef",
     "CreateEndpointAccessRequestRequestTypeDef",
-    "TagTypeDef",
     "NamespaceTypeDef",
-    "CreateSnapshotRequestRequestTypeDef",
     "CreateUsageLimitRequestRequestTypeDef",
     "UsageLimitTypeDef",
     "DeleteEndpointAccessRequestRequestTypeDef",
@@ -57,6 +55,8 @@ __all__ = (
     "GetResourcePolicyRequestRequestTypeDef",
     "ResourcePolicyTypeDef",
     "GetSnapshotRequestRequestTypeDef",
+    "GetTableRestoreStatusRequestRequestTypeDef",
+    "TableRestoreStatusTypeDef",
     "GetUsageLimitRequestRequestTypeDef",
     "GetWorkgroupRequestRequestTypeDef",
     "PaginatorConfigTypeDef",
@@ -64,6 +64,7 @@ __all__ = (
     "ListNamespacesRequestRequestTypeDef",
     "ListRecoveryPointsRequestRequestTypeDef",
     "ListSnapshotsRequestRequestTypeDef",
+    "ListTableRestoreStatusRequestRequestTypeDef",
     "ListTagsForResourceRequestRequestTypeDef",
     "ListUsageLimitsRequestRequestTypeDef",
     "ListWorkgroupsRequestRequestTypeDef",
@@ -71,23 +72,26 @@ __all__ = (
     "PutResourcePolicyRequestRequestTypeDef",
     "RestoreFromRecoveryPointRequestRequestTypeDef",
     "RestoreFromSnapshotRequestRequestTypeDef",
+    "RestoreTableFromSnapshotRequestRequestTypeDef",
     "UntagResourceRequestRequestTypeDef",
     "UpdateEndpointAccessRequestRequestTypeDef",
     "UpdateNamespaceRequestRequestTypeDef",
     "UpdateSnapshotRequestRequestTypeDef",
     "UpdateUsageLimitRequestRequestTypeDef",
     "UpdateWorkgroupRequestRequestTypeDef",
+    "ConvertRecoveryPointToSnapshotRequestRequestTypeDef",
+    "CreateNamespaceRequestRequestTypeDef",
+    "CreateSnapshotRequestRequestTypeDef",
+    "CreateWorkgroupRequestRequestTypeDef",
+    "TagResourceRequestRequestTypeDef",
     "GetCredentialsResponseTypeDef",
+    "ListTagsForResourceResponseTypeDef",
     "ConvertRecoveryPointToSnapshotResponseTypeDef",
     "CreateSnapshotResponseTypeDef",
     "DeleteSnapshotResponseTypeDef",
     "GetSnapshotResponseTypeDef",
     "ListSnapshotsResponseTypeDef",
     "UpdateSnapshotResponseTypeDef",
-    "CreateNamespaceRequestRequestTypeDef",
-    "CreateWorkgroupRequestRequestTypeDef",
-    "ListTagsForResourceResponseTypeDef",
-    "TagResourceRequestRequestTypeDef",
     "CreateNamespaceResponseTypeDef",
     "DeleteNamespaceResponseTypeDef",
     "GetNamespaceResponseTypeDef",
@@ -104,10 +108,14 @@ __all__ = (
     "ListRecoveryPointsResponseTypeDef",
     "GetResourcePolicyResponseTypeDef",
     "PutResourcePolicyResponseTypeDef",
+    "GetTableRestoreStatusResponseTypeDef",
+    "ListTableRestoreStatusResponseTypeDef",
+    "RestoreTableFromSnapshotResponseTypeDef",
     "ListEndpointAccessRequestListEndpointAccessPaginateTypeDef",
     "ListNamespacesRequestListNamespacesPaginateTypeDef",
     "ListRecoveryPointsRequestListRecoveryPointsPaginateTypeDef",
     "ListSnapshotsRequestListSnapshotsPaginateTypeDef",
+    "ListTableRestoreStatusRequestListTableRestoreStatusPaginateTypeDef",
     "ListUsageLimitsRequestListUsageLimitsPaginateTypeDef",
     "ListWorkgroupsRequestListWorkgroupsPaginateTypeDef",
     "VpcEndpointTypeDef",
@@ -135,28 +143,13 @@ ConfigParameterTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredConvertRecoveryPointToSnapshotRequestRequestTypeDef = TypedDict(
-    "_RequiredConvertRecoveryPointToSnapshotRequestRequestTypeDef",
+TagTypeDef = TypedDict(
+    "TagTypeDef",
     {
-        "recoveryPointId": str,
-        "snapshotName": str,
+        "key": str,
+        "value": str,
     },
 )
-_OptionalConvertRecoveryPointToSnapshotRequestRequestTypeDef = TypedDict(
-    "_OptionalConvertRecoveryPointToSnapshotRequestRequestTypeDef",
-    {
-        "retentionPeriod": int,
-    },
-    total=False,
-)
-
-
-class ConvertRecoveryPointToSnapshotRequestRequestTypeDef(
-    _RequiredConvertRecoveryPointToSnapshotRequestRequestTypeDef,
-    _OptionalConvertRecoveryPointToSnapshotRequestRequestTypeDef,
-):
-    pass
-
 
 ResponseMetadataTypeDef = TypedDict(
     "ResponseMetadataTypeDef",
@@ -220,14 +213,6 @@ class CreateEndpointAccessRequestRequestTypeDef(
     pass
 
 
-TagTypeDef = TypedDict(
-    "TagTypeDef",
-    {
-        "key": str,
-        "value": str,
-    },
-)
-
 NamespaceTypeDef = TypedDict(
     "NamespaceTypeDef",
     {
@@ -246,28 +231,6 @@ NamespaceTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredCreateSnapshotRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateSnapshotRequestRequestTypeDef",
-    {
-        "namespaceName": str,
-        "snapshotName": str,
-    },
-)
-_OptionalCreateSnapshotRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateSnapshotRequestRequestTypeDef",
-    {
-        "retentionPeriod": int,
-    },
-    total=False,
-)
-
-
-class CreateSnapshotRequestRequestTypeDef(
-    _RequiredCreateSnapshotRequestRequestTypeDef, _OptionalCreateSnapshotRequestRequestTypeDef
-):
-    pass
-
-
 _RequiredCreateUsageLimitRequestRequestTypeDef = TypedDict(
     "_RequiredCreateUsageLimitRequestRequestTypeDef",
     {
@@ -418,6 +381,7 @@ GetRecoveryPointRequestRequestTypeDef = TypedDict(
 RecoveryPointTypeDef = TypedDict(
     "RecoveryPointTypeDef",
     {
+        "namespaceArn": str,
         "namespaceName": str,
         "recoveryPointCreateTime": datetime,
         "recoveryPointId": str,
@@ -453,6 +417,35 @@ GetSnapshotRequestRequestTypeDef = TypedDict(
     total=False,
 )
 
+GetTableRestoreStatusRequestRequestTypeDef = TypedDict(
+    "GetTableRestoreStatusRequestRequestTypeDef",
+    {
+        "tableRestoreRequestId": str,
+    },
+)
+
+TableRestoreStatusTypeDef = TypedDict(
+    "TableRestoreStatusTypeDef",
+    {
+        "message": str,
+        "namespaceName": str,
+        "newTableName": str,
+        "progressInMegaBytes": int,
+        "requestTime": datetime,
+        "snapshotName": str,
+        "sourceDatabaseName": str,
+        "sourceSchemaName": str,
+        "sourceTableName": str,
+        "status": str,
+        "tableRestoreRequestId": str,
+        "targetDatabaseName": str,
+        "targetSchemaName": str,
+        "totalDataInMegaBytes": int,
+        "workgroupName": str,
+    },
+    total=False,
+)
+
 GetUsageLimitRequestRequestTypeDef = TypedDict(
     "GetUsageLimitRequestRequestTypeDef",
     {
@@ -502,6 +495,7 @@ ListRecoveryPointsRequestRequestTypeDef = TypedDict(
     {
         "endTime": Union[datetime, str],
         "maxResults": int,
+        "namespaceArn": str,
         "namespaceName": str,
         "nextToken": str,
         "startTime": Union[datetime, str],
@@ -523,6 +517,17 @@ ListSnapshotsRequestRequestTypeDef = TypedDict(
     total=False,
 )
 
+ListTableRestoreStatusRequestRequestTypeDef = TypedDict(
+    "ListTableRestoreStatusRequestRequestTypeDef",
+    {
+        "maxResults": int,
+        "namespaceName": str,
+        "nextToken": str,
+        "workgroupName": str,
+    },
+    total=False,
+)
+
 ListTagsForResourceRequestRequestTypeDef = TypedDict(
     "ListTagsForResourceRequestRequestTypeDef",
     {
@@ -603,6 +608,36 @@ class RestoreFromSnapshotRequestRequestTypeDef(
     pass
 
 
+_RequiredRestoreTableFromSnapshotRequestRequestTypeDef = TypedDict(
+    "_RequiredRestoreTableFromSnapshotRequestRequestTypeDef",
+    {
+        "namespaceName": str,
+        "newTableName": str,
+        "snapshotName": str,
+        "sourceDatabaseName": str,
+        "sourceTableName": str,
+        "workgroupName": str,
+    },
+)
+_OptionalRestoreTableFromSnapshotRequestRequestTypeDef = TypedDict(
+    "_OptionalRestoreTableFromSnapshotRequestRequestTypeDef",
+    {
+        "activateCaseSensitiveIdentifier": bool,
+        "sourceSchemaName": str,
+        "targetDatabaseName": str,
+        "targetSchemaName": str,
+    },
+    total=False,
+)
+
+
+class RestoreTableFromSnapshotRequestRequestTypeDef(
+    _RequiredRestoreTableFromSnapshotRequestRequestTypeDef,
+    _OptionalRestoreTableFromSnapshotRequestRequestTypeDef,
+):
+    pass
+
+
 UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
@@ -714,6 +749,7 @@ _OptionalUpdateWorkgroupRequestRequestTypeDef = TypedDict(
         "baseCapacity": int,
         "configParameters": Sequence[ConfigParameterTypeDef],
         "enhancedVpcRouting": bool,
+        "port": int,
         "publiclyAccessible": bool,
         "securityGroupIds": Sequence[str],
         "subnetIds": Sequence[str],
@@ -728,6 +764,118 @@ class UpdateWorkgroupRequestRequestTypeDef(
     pass
 
 
+_RequiredConvertRecoveryPointToSnapshotRequestRequestTypeDef = TypedDict(
+    "_RequiredConvertRecoveryPointToSnapshotRequestRequestTypeDef",
+    {
+        "recoveryPointId": str,
+        "snapshotName": str,
+    },
+)
+_OptionalConvertRecoveryPointToSnapshotRequestRequestTypeDef = TypedDict(
+    "_OptionalConvertRecoveryPointToSnapshotRequestRequestTypeDef",
+    {
+        "retentionPeriod": int,
+        "tags": Sequence[TagTypeDef],
+    },
+    total=False,
+)
+
+
+class ConvertRecoveryPointToSnapshotRequestRequestTypeDef(
+    _RequiredConvertRecoveryPointToSnapshotRequestRequestTypeDef,
+    _OptionalConvertRecoveryPointToSnapshotRequestRequestTypeDef,
+):
+    pass
+
+
+_RequiredCreateNamespaceRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateNamespaceRequestRequestTypeDef",
+    {
+        "namespaceName": str,
+    },
+)
+_OptionalCreateNamespaceRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateNamespaceRequestRequestTypeDef",
+    {
+        "adminUserPassword": str,
+        "adminUsername": str,
+        "dbName": str,
+        "defaultIamRoleArn": str,
+        "iamRoles": Sequence[str],
+        "kmsKeyId": str,
+        "logExports": Sequence[LogExportType],
+        "tags": Sequence[TagTypeDef],
+    },
+    total=False,
+)
+
+
+class CreateNamespaceRequestRequestTypeDef(
+    _RequiredCreateNamespaceRequestRequestTypeDef, _OptionalCreateNamespaceRequestRequestTypeDef
+):
+    pass
+
+
+_RequiredCreateSnapshotRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateSnapshotRequestRequestTypeDef",
+    {
+        "namespaceName": str,
+        "snapshotName": str,
+    },
+)
+_OptionalCreateSnapshotRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateSnapshotRequestRequestTypeDef",
+    {
+        "retentionPeriod": int,
+        "tags": Sequence[TagTypeDef],
+    },
+    total=False,
+)
+
+
+class CreateSnapshotRequestRequestTypeDef(
+    _RequiredCreateSnapshotRequestRequestTypeDef, _OptionalCreateSnapshotRequestRequestTypeDef
+):
+    pass
+
+
+_RequiredCreateWorkgroupRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateWorkgroupRequestRequestTypeDef",
+    {
+        "namespaceName": str,
+        "workgroupName": str,
+    },
+)
+_OptionalCreateWorkgroupRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateWorkgroupRequestRequestTypeDef",
+    {
+        "baseCapacity": int,
+        "configParameters": Sequence[ConfigParameterTypeDef],
+        "enhancedVpcRouting": bool,
+        "port": int,
+        "publiclyAccessible": bool,
+        "securityGroupIds": Sequence[str],
+        "subnetIds": Sequence[str],
+        "tags": Sequence[TagTypeDef],
+    },
+    total=False,
+)
+
+
+class CreateWorkgroupRequestRequestTypeDef(
+    _RequiredCreateWorkgroupRequestRequestTypeDef, _OptionalCreateWorkgroupRequestRequestTypeDef
+):
+    pass
+
+
+TagResourceRequestRequestTypeDef = TypedDict(
+    "TagResourceRequestRequestTypeDef",
+    {
+        "resourceArn": str,
+        "tags": Sequence[TagTypeDef],
+    },
+)
+
 GetCredentialsResponseTypeDef = TypedDict(
     "GetCredentialsResponseTypeDef",
     {
@@ -739,6 +887,14 @@ GetCredentialsResponseTypeDef = TypedDict(
     },
 )
 
+ListTagsForResourceResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseTypeDef",
+    {
+        "tags": List[TagTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 ConvertRecoveryPointToSnapshotResponseTypeDef = TypedDict(
     "ConvertRecoveryPointToSnapshotResponseTypeDef",
     {
@@ -788,78 +944,6 @@ UpdateSnapshotResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateNamespaceRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateNamespaceRequestRequestTypeDef",
-    {
-        "namespaceName": str,
-    },
-)
-_OptionalCreateNamespaceRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateNamespaceRequestRequestTypeDef",
-    {
-        "adminUserPassword": str,
-        "adminUsername": str,
-        "dbName": str,
-        "defaultIamRoleArn": str,
-        "iamRoles": Sequence[str],
-        "kmsKeyId": str,
-        "logExports": Sequence[LogExportType],
-        "tags": Sequence[TagTypeDef],
-    },
-    total=False,
-)
-
-
-class CreateNamespaceRequestRequestTypeDef(
-    _RequiredCreateNamespaceRequestRequestTypeDef, _OptionalCreateNamespaceRequestRequestTypeDef
-):
-    pass
-
-
-_RequiredCreateWorkgroupRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateWorkgroupRequestRequestTypeDef",
-    {
-        "namespaceName": str,
-        "workgroupName": str,
-    },
-)
-_OptionalCreateWorkgroupRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateWorkgroupRequestRequestTypeDef",
-    {
-        "baseCapacity": int,
-        "configParameters": Sequence[ConfigParameterTypeDef],
-        "enhancedVpcRouting": bool,
-        "publiclyAccessible": bool,
-        "securityGroupIds": Sequence[str],
-        "subnetIds": Sequence[str],
-        "tags": Sequence[TagTypeDef],
-    },
-    total=False,
-)
-
-
-class CreateWorkgroupRequestRequestTypeDef(
-    _RequiredCreateWorkgroupRequestRequestTypeDef, _OptionalCreateWorkgroupRequestRequestTypeDef
-):
-    pass
-
-
-ListTagsForResourceResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseTypeDef",
-    {
-        "tags": List[TagTypeDef],
-        "ResponseMetadata": ResponseMetadataTypeDef,
-    },
-)
-
-TagResourceRequestRequestTypeDef = TypedDict(
-    "TagResourceRequestRequestTypeDef",
-    {
-        "resourceArn": str,
-        "tags": Sequence[TagTypeDef],
-    },
-)
-
 CreateNamespaceResponseTypeDef = TypedDict(
     "CreateNamespaceResponseTypeDef",
     {
@@ -994,6 +1078,31 @@ PutResourcePolicyResponseTypeDef = TypedDict(
     },
 )
 
+GetTableRestoreStatusResponseTypeDef = TypedDict(
+    "GetTableRestoreStatusResponseTypeDef",
+    {
+        "tableRestoreStatus": TableRestoreStatusTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListTableRestoreStatusResponseTypeDef = TypedDict(
+    "ListTableRestoreStatusResponseTypeDef",
+    {
+        "nextToken": str,
+        "tableRestoreStatuses": List[TableRestoreStatusTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+RestoreTableFromSnapshotResponseTypeDef = TypedDict(
+    "RestoreTableFromSnapshotResponseTypeDef",
+    {
+        "tableRestoreStatus": TableRestoreStatusTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 ListEndpointAccessRequestListEndpointAccessPaginateTypeDef = TypedDict(
     "ListEndpointAccessRequestListEndpointAccessPaginateTypeDef",
     {
@@ -1016,6 +1125,7 @@ ListRecoveryPointsRequestListRecoveryPointsPaginateTypeDef = TypedDict(
     "ListRecoveryPointsRequestListRecoveryPointsPaginateTypeDef",
     {
         "endTime": Union[datetime, str],
+        "namespaceArn": str,
         "namespaceName": str,
         "startTime": Union[datetime, str],
         "PaginationConfig": PaginatorConfigTypeDef,
@@ -1036,6 +1146,16 @@ ListSnapshotsRequestListSnapshotsPaginateTypeDef = TypedDict(
     total=False,
 )
 
+ListTableRestoreStatusRequestListTableRestoreStatusPaginateTypeDef = TypedDict(
+    "ListTableRestoreStatusRequestListTableRestoreStatusPaginateTypeDef",
+    {
+        "namespaceName": str,
+        "workgroupName": str,
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
 ListUsageLimitsRequestListUsageLimitsPaginateTypeDef = TypedDict(
     "ListUsageLimitsRequestListUsageLimitsPaginateTypeDef",
     {
@@ -1141,6 +1261,7 @@ WorkgroupTypeDef = TypedDict(
         "endpoint": EndpointTypeDef,
         "enhancedVpcRouting": bool,
         "namespaceName": str,
+        "port": int,
         "publiclyAccessible": bool,
         "securityGroupIds": List[str],
         "status": WorkgroupStatusType,
